@@ -6,6 +6,8 @@ use cargo::util::{CliResult, CliError, Config};
 #[derive(RustcDecodable)]
 struct Options {
     flag_verbose: bool,
+    flag_quiet: bool,
+    flag_color: Option<String>,
     flag_bin: bool,
     arg_path: String,
     flag_name: Option<String>,
@@ -21,17 +23,20 @@ Usage:
 
 Options:
     -h, --help          Print this message
-    --vcs <vcs>         Initialize a new repository for the given version
+    --vcs VCS           Initialize a new repository for the given version
                         control system (git or hg) or do not initialize any version
                         control at all (none) overriding a global configuration.
     --bin               Use a binary instead of a library template
-    --name <name>       Set the resulting package name
+    --name NAME         Set the resulting package name
     -v, --verbose       Use verbose output
+    -q, --quiet         No output printed to stdout
+    --color WHEN        Coloring: auto, always, never
 ";
 
 pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
     debug!("executing; cmd=cargo-new; args={:?}", env::args().collect::<Vec<_>>());
-    config.shell().set_verbose(options.flag_verbose);
+    try!(config.shell().set_verbosity(options.flag_verbose, options.flag_quiet));
+    try!(config.shell().set_color_config(options.flag_color.as_ref().map(|s| &s[..])));
 
     let Options { flag_bin, arg_path, flag_name, flag_vcs, .. } = options;
 
@@ -47,4 +52,3 @@ pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
     })
 }
 
-
