@@ -5,6 +5,8 @@ use cargo::util::{CliResult, CliError, Config};
 struct Options {
     flag_host: Option<String>,
     flag_verbose: bool,
+    flag_quiet: bool,
+    flag_color: Option<String>,
     arg_query: String
 }
 
@@ -16,13 +18,16 @@ Usage:
     cargo search [-h | --help]
 
 Options:
-    -h, --help              Print this message
-    --host HOST             Host of a registry to search in
-    -v, --verbose           Use verbose output
+    -h, --help               Print this message
+    --host HOST              Host of a registry to search in
+    -v, --verbose            Use verbose output
+    -q, --quiet              No output printed to stdout
+    --color WHEN             Coloring: auto, always, never
 ";
 
 pub fn execute(options: Options, config: &Config) -> CliResult<Option<()>> {
-    config.shell().set_verbose(options.flag_verbose);
+    try!(config.shell().set_verbosity(options.flag_verbose, options.flag_quiet));
+    try!(config.shell().set_color_config(options.flag_color.as_ref().map(|s| &s[..])));
     let Options {
         flag_host: host,
         arg_query: query,
