@@ -5,13 +5,12 @@ use cargo::util::process;
 use support::{project, execs, cargo_dir};
 use support::{UPDATING, DOWNLOADING, COMPILING, PACKAGING, VERIFYING, ADDING, REMOVING};
 use support::paths::{self, CargoPathExt};
-use support::registry as r;
+use support::registry::{self, Package};
 use support::git;
 
 use hamcrest::assert_that;
 
 fn setup() {
-    r::init();
 }
 
 test!(simple {
@@ -27,7 +26,7 @@ test!(simple {
         "#)
         .file("src/main.rs", "fn main() {}");
 
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
 
     assert_that(p.cargo_process("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -40,7 +39,7 @@ test!(simple {
         downloading = DOWNLOADING,
         compiling = COMPILING,
         dir = p.url(),
-        reg = r::registry())));
+        reg = registry::registry())));
 
     // Don't download a second time
     assert_that(p.cargo_process("build"),
@@ -51,7 +50,7 @@ test!(simple {
 ",
         updating = UPDATING,
         dir = p.url(),
-        reg = r::registry())));
+        reg = registry::registry())));
 });
 
 test!(deps {
@@ -67,8 +66,8 @@ test!(deps {
         "#)
         .file("src/main.rs", "fn main() {}");
 
-    r::mock_pkg("baz", "0.0.1", &[]);
-    r::mock_pkg("bar", "0.0.1", &[("baz", "*", "normal")]);
+    Package::new("baz", "0.0.1").publish();
+    Package::new("bar", "0.0.1").dep("baz", "*").publish();
 
     assert_that(p.cargo_process("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -83,10 +82,12 @@ test!(deps {
         downloading = DOWNLOADING,
         compiling = COMPILING,
         dir = p.url(),
-        reg = r::registry())));
+        reg = registry::registry())));
 });
 
 test!(nonexistent {
+    Package::new("init", "0.0.1").publish();
+
     let p = project("foo")
         .file("Cargo.toml", r#"
             [project]
@@ -120,8 +121,8 @@ test!(wrong_version {
         "#)
         .file("src/main.rs", "fn main() {}");
 
-    r::mock_pkg("foo", "0.0.1", &[]);
-    r::mock_pkg("foo", "0.0.2", &[]);
+    Package::new("foo", "0.0.1").publish();
+    Package::new("foo", "0.0.2").publish();
 
     assert_that(p.cargo_process("build"),
                 execs().with_status(101).with_stderr("\
@@ -131,8 +132,8 @@ version required: >= 1.0.0
 versions found: 0.0.2, 0.0.1
 "));
 
-    r::mock_pkg("foo", "0.0.3", &[]);
-    r::mock_pkg("foo", "0.0.4", &[]);
+    Package::new("foo", "0.0.3").publish();
+    Package::new("foo", "0.0.4").publish();
 
     assert_that(p.cargo_process("build"),
                 execs().with_status(101).with_stderr("\
@@ -156,22 +157,25 @@ test!(bad_cksum {
         "#)
         .file("src/main.rs", "fn main() {}");
 
-    r::mock_pkg("bad-cksum", "0.0.1", &[]);
-    File::create(&r::mock_archive_dst("bad-cksum", "0.0.1")).unwrap();
+    let pkg = Package::new("bad-cksum", "0.0.1");
+    pkg.publish();
+    File::create(&pkg.archive_dst()).unwrap();
 
     assert_that(p.cargo_process("build").arg("-v"),
                 execs().with_status(101).with_stderr("\
 unable to get packages from source
 
 Caused by:
-  Failed to download package `bad-cksum v0.0.1 (registry file://[..])` from [..]
+  failed to download package `bad-cksum v0.0.1 (registry file://[..])` from [..]
 
 Caused by:
-  Failed to verify the checksum of `bad-cksum v0.0.1 (registry file://[..])`
+  failed to verify the checksum of `bad-cksum v0.0.1 (registry file://[..])`
 "));
 });
 
 test!(update_registry {
+    Package::new("init", "0.0.1").publish();
+
     let p = project("foo")
         .file("Cargo.toml", r#"
             [project]
@@ -191,7 +195,7 @@ location searched: registry file://[..]
 version required: >= 0.0.0
 "));
 
-    r::mock_pkg("notyet", "0.0.1", &[]);
+    Package::new("notyet", "0.0.1").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -204,10 +208,12 @@ version required: >= 0.0.0
         downloading = DOWNLOADING,
         compiling = COMPILING,
         dir = p.url(),
-        reg = r::registry())));
+        reg = registry::registry())));
 });
 
 test!(package_with_path_deps {
+    Package::new("init", "0.0.1").publish();
+
     let p = project("foo")
         .file("Cargo.toml", r#"
             [project]
@@ -242,7 +248,7 @@ location searched: registry file://[..]
 version required: ^0.0.1
 "));
 
-    r::mock_pkg("notyet", "0.0.1", &[]);
+    Package::new("notyet", "0.0.1").publish();
 
     assert_that(p.cargo("package"),
                 execs().with_status(0).with_stdout(format!("\
@@ -276,7 +282,7 @@ test!(lockfile_locks {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -288,7 +294,7 @@ test!(lockfile_locks {
    dir = p.url())));
 
     p.root().move_into_the_past().unwrap();
-    r::mock_pkg("bar", "0.0.2", &[]);
+    Package::new("bar", "0.0.2").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(""));
@@ -308,8 +314,8 @@ test!(lockfile_locks_transitively {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("baz", "0.0.1", &[]);
-    r::mock_pkg("bar", "0.0.1", &[("baz", "*", "normal")]);
+    Package::new("baz", "0.0.1").publish();
+    Package::new("bar", "0.0.1").dep("baz", "*").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -323,8 +329,8 @@ test!(lockfile_locks_transitively {
    dir = p.url())));
 
     p.root().move_into_the_past().unwrap();
-    r::mock_pkg("baz", "0.0.2", &[]);
-    r::mock_pkg("bar", "0.0.2", &[("baz", "*", "normal")]);
+    Package::new("baz", "0.0.2").publish();
+    Package::new("bar", "0.0.2").dep("baz", "*").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(""));
@@ -344,10 +350,10 @@ test!(yanks_are_not_used {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("baz", "0.0.1", &[]);
-    r::mock_pkg_yank("baz", "0.0.2", &[], true);
-    r::mock_pkg("bar", "0.0.1", &[("baz", "*", "normal")]);
-    r::mock_pkg_yank("bar", "0.0.2", &[("baz", "*", "normal")], true);
+    Package::new("baz", "0.0.1").publish();
+    Package::new("baz", "0.0.2").yanked(true).publish();
+    Package::new("bar", "0.0.1").dep("baz", "*").publish();
+    Package::new("bar", "0.0.2").dep("baz", "*").yanked(true).publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -375,9 +381,9 @@ test!(relying_on_a_yank_is_bad {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("baz", "0.0.1", &[]);
-    r::mock_pkg_yank("baz", "0.0.2", &[], true);
-    r::mock_pkg("bar", "0.0.1", &[("baz", "=0.0.2", "normal")]);
+    Package::new("baz", "0.0.1").publish();
+    Package::new("baz", "0.0.2").yanked(true).publish();
+    Package::new("bar", "0.0.1").dep("baz", "=0.0.2").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(101).with_stderr("\
@@ -402,14 +408,14 @@ test!(yanks_in_lockfiles_are_ok {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0));
 
-    fs::remove_dir_all(&r::registry_path().join("3")).unwrap();
+    fs::remove_dir_all(&registry::registry_path().join("3")).unwrap();
 
-    r::mock_pkg_yank("bar", "0.0.1", &[], true);
+    Package::new("bar", "0.0.1").yanked(true).publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(""));
@@ -436,7 +442,7 @@ test!(update_with_lockfile_if_packages_missing {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
     assert_that(p.cargo("build"),
                 execs().with_status(0));
     p.root().move_into_the_past().unwrap();
@@ -464,12 +470,12 @@ test!(update_lockfile {
     p.build();
 
     println!("0.0.1");
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
     assert_that(p.cargo("build"),
                 execs().with_status(0));
 
-    r::mock_pkg("bar", "0.0.2", &[]);
-    r::mock_pkg("bar", "0.0.3", &[]);
+    Package::new("bar", "0.0.2").publish();
+    Package::new("bar", "0.0.3").publish();
     paths::home().join(".cargo/registry").rm_rf().unwrap();
     println!("0.0.2 update");
     assert_that(p.cargo("update")
@@ -506,8 +512,8 @@ test!(update_lockfile {
    dir = p.url())));
 
    println!("new dependencies update");
-   r::mock_pkg("bar", "0.0.4", &[("spam", "0.2.5", "")]);
-   r::mock_pkg("spam", "0.2.5", &[]);
+   Package::new("bar", "0.0.4").dep("spam", "0.2.5").publish();
+   Package::new("spam", "0.2.5").publish();
    assert_that(p.cargo("update")
                 .arg("-p").arg("bar"),
                execs().with_status(0).with_stdout(&format!("\
@@ -517,7 +523,7 @@ test!(update_lockfile {
 ", updating = UPDATING, adding = ADDING)));
 
    println!("new dependencies update");
-   r::mock_pkg("bar", "0.0.5", &[]);
+   Package::new("bar", "0.0.5").publish();
    assert_that(p.cargo("update")
                 .arg("-p").arg("bar"),
                execs().with_status(0).with_stdout(&format!("\
@@ -541,8 +547,8 @@ test!(dev_dependency_not_used {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("baz", "0.0.1", &[]);
-    r::mock_pkg("bar", "0.0.1", &[("baz", "*", "dev")]);
+    Package::new("baz", "0.0.1").publish();
+    Package::new("bar", "0.0.1").dev_dep("baz", "*").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -557,7 +563,7 @@ test!(dev_dependency_not_used {
 test!(login_with_no_cargo_dir {
     let home = paths::home().join("new-home");
     fs::create_dir(&home).unwrap();
-    assert_that(process(&cargo_dir().join("cargo")).unwrap()
+    assert_that(process(&cargo_dir().join("cargo"))
                        .arg("login").arg("foo").arg("-v")
                        .cwd(&paths::root())
                        .env("HOME", &home),
@@ -608,7 +614,7 @@ test!(updating_a_dep {
         .file("a/src/lib.rs", "");
     p.build();
 
-    r::mock_pkg("bar", "0.0.1", &[]);
+    Package::new("bar", "0.0.1").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0).with_stdout(&format!("\
@@ -629,7 +635,7 @@ test!(updating_a_dep {
         [dependencies]
         bar = "0.1.0"
     "#).unwrap();
-    r::mock_pkg("bar", "0.1.0", &[]);
+    Package::new("bar", "0.1.0").publish();
 
     println!("second");
     assert_that(p.cargo("build"),
@@ -672,7 +678,7 @@ test!(git_and_registry_dep {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("a", "0.0.1", &[]);
+    Package::new("a", "0.0.1").publish();
 
     p.root().move_into_the_past().unwrap();
     assert_that(p.cargo("build"),
@@ -706,13 +712,12 @@ test!(update_publish_then_update {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("a", "0.1.0", &[]);
+    Package::new("a", "0.1.0").publish();
 
     assert_that(p.cargo("build"),
                 execs().with_status(0));
 
-
-    r::mock_pkg("a", "0.1.1", &[]);
+    Package::new("a", "0.1.1").publish();
 
     let lock = p.root().join("Cargo.lock");
     let mut s = String::new();
@@ -747,7 +752,7 @@ test!(fetch_downloads {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("a", "0.1.0", &[]);
+    Package::new("a", "0.1.0").publish();
 
     assert_that(p.cargo("fetch"),
                 execs().with_status(0)
@@ -771,13 +776,13 @@ test!(update_transitive_dependency {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("a", "0.1.0", &[("b", "*", "normal")]);
-    r::mock_pkg("b", "0.1.0", &[]);
+    Package::new("a", "0.1.0").dep("b", "*").publish();
+    Package::new("b", "0.1.0").publish();
 
     assert_that(p.cargo("fetch"),
                 execs().with_status(0));
 
-    r::mock_pkg("b", "0.1.1", &[]);
+    Package::new("b", "0.1.1").publish();
 
     assert_that(p.cargo("update").arg("-pb"),
                 execs().with_status(0)
@@ -810,18 +815,20 @@ test!(update_backtracking_ok {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("webdriver", "0.1.0", &[("hyper", "0.6", "normal")]);
-    r::mock_pkg("hyper", "0.6.5", &[("openssl", "0.1", "normal"),
-                                    ("cookie", "0.1", "normal")]);
-    r::mock_pkg("cookie", "0.1.0", &[("openssl", "0.1", "normal")]);
-    r::mock_pkg("openssl", "0.1.0", &[]);
+    Package::new("webdriver", "0.1.0").dep("hyper", "0.6").publish();
+    Package::new("hyper", "0.6.5").dep("openssl", "0.1")
+                                  .dep("cookie", "0.1")
+                                  .publish();
+    Package::new("cookie", "0.1.0").dep("openssl", "0.1").publish();
+    Package::new("openssl", "0.1.0").publish();
 
     assert_that(p.cargo("generate-lockfile"),
                 execs().with_status(0));
 
-    r::mock_pkg("openssl", "0.1.1", &[]);
-    r::mock_pkg("hyper", "0.6.6", &[("openssl", "0.1.1", "normal"),
-                                    ("cookie", "0.1.0", "normal")]);
+    Package::new("openssl", "0.1.1").publish();
+    Package::new("hyper", "0.6.6").dep("openssl", "0.1.1")
+                                  .dep("cookie", "0.1.0")
+                                  .publish();
 
     assert_that(p.cargo("update").arg("-p").arg("hyper"),
                 execs().with_status(0)
@@ -846,16 +853,16 @@ test!(update_multiple_packages {
         .file("src/main.rs", "fn main() {}");
     p.build();
 
-    r::mock_pkg("a", "0.1.0", &[]);
-    r::mock_pkg("b", "0.1.0", &[]);
-    r::mock_pkg("c", "0.1.0", &[]);
+    Package::new("a", "0.1.0").publish();
+    Package::new("b", "0.1.0").publish();
+    Package::new("c", "0.1.0").publish();
 
     assert_that(p.cargo("fetch"),
                 execs().with_status(0));
 
-    r::mock_pkg("a", "0.1.1", &[]);
-    r::mock_pkg("b", "0.1.1", &[]);
-    r::mock_pkg("c", "0.1.1", &[]);
+    Package::new("a", "0.1.1").publish();
+    Package::new("b", "0.1.1").publish();
+    Package::new("c", "0.1.1").publish();
 
     assert_that(p.cargo("update").arg("-pa").arg("-pb"),
                 execs().with_status(0)
@@ -889,3 +896,43 @@ test!(update_multiple_packages {
                        .with_stdout_contains(format!("\
 {compiling} foo v0.5.0 ([..])", compiling = COMPILING)));
 });
+
+test!(bundled_crate_in_registry {
+    let p = project("foo")
+        .file("Cargo.toml", r#"
+            [project]
+            name = "foo"
+            version = "0.5.0"
+            authors = []
+
+            [dependencies]
+            bar = "0.1"
+            baz = "0.1"
+        "#)
+        .file("src/main.rs", "fn main() {}");
+    p.build();
+
+    Package::new("bar", "0.1.0").publish();
+    Package::new("baz", "0.1.0")
+        .dep("bar", "0.1.0")
+        .file("Cargo.toml", r#"
+            [package]
+            name = "baz"
+            version = "0.1.0"
+            authors = []
+
+            [dependencies]
+            bar = { path = "bar", version = "0.1.0" }
+        "#)
+        .file("src/lib.rs", "")
+        .file("bar/Cargo.toml", r#"
+            [package]
+            name = "bar"
+            version = "0.1.0"
+            authors = []
+        "#)
+        .file("bar/src/lib.rs", "")
+        .publish();
+
+    assert_that(p.cargo("run"), execs().with_status(0));
+});
